@@ -5,7 +5,7 @@ package DBIx::SearchBuilder;
 use strict;
 use vars qw($VERSION);
 
-$VERSION = "0.97";
+$VERSION = "0.99";
 
 =head1 NAME
 
@@ -70,7 +70,6 @@ sub CleanSlate {
     $self->{'tables'}           = "";
     $self->{'auxillary_tables'} = "";
     $self->{'where_clause'}     = "";
-    $self->{'table_links'}      = "";
     $self->{'limit_clause'}     = "";
     $self->{'order'}            = "";
     $self->{'alias_count'}      = 0;
@@ -108,7 +107,7 @@ sub _DoSearch {
     # The initial SELECT or SELECT DISTINCT is decided later
 
     $QueryString = $self->_BuildJoins . " ";
-    $QueryString .= $self->_WhereClause . " " . $self->{'table_links'} . " "
+    $QueryString .= $self->_WhereClause . " "
       if ( $self->_isLimited > 0 );
 
     # DISTINCT query only required for multi-table selects
@@ -206,7 +205,7 @@ sub _DoCount {
 
     $QueryString .= $self->_BuildJoins . " ";
 
-    $QueryString .= $self->_WhereClause . " " . $self->{'table_links'} . " "
+    $QueryString .= $self->_WhereClause . " "
       if ( $self->_isLimited > 0 );
 
 
@@ -878,7 +877,6 @@ sub _WhereClause {
     #Go through all restriction types. Build the where clause from the
     #Various subclauses.
     foreach $subclause ( keys %{ $self->{'subclauses'} } ) {
-
         # Now, build up the where clause
         if ( defined($where_clause) ) {
             $where_clause .= " AND ";
@@ -890,7 +888,9 @@ sub _WhereClause {
     }
 
     $where_clause = " WHERE " . $where_clause if ( $where_clause ne '' );
+
     return ($where_clause);
+
 }
 
 # }}}
@@ -1088,23 +1088,22 @@ the alias generated by the join.
 
 sub Join {
     my $self = shift;
-    my %args = ( TYPE   => 'normal',
-                 FIELD1 => undef, ALIAS1 => undef,
-                 TABLE2 => undef, FIELD2 => undef, ALIAS2 => undef,
-                 @_ );
-
-    $self->_Handle->Join(SearchBuilder => $self, %args);
-
+    my %args = (
+        TYPE   => 'normal',
+        FIELD1 => undef,
+        ALIAS1 => undef,
+        TABLE2 => undef,
+        FIELD2 => undef,
+        ALIAS2 => undef,
+        @_
+    );
 
+    $self->_Handle->Join( SearchBuilder => $self, %args );
 
 }
 
 # }}}
 
-# things we'll want to add:
-# get aliases
-# add restirction clause
-
 # }}}
 
 # {{{ Deal with 'pages' of results'
